==> jc-1.4.0.tar.gz: java/awt/event/AdjustmentEvent.h <==
// public class java.awt.event.AdjustmentEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 7367f28289e75fa5 java_awt_event_AdjustmentEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_AdjustmentEvent_H_
#define _JC_java_awt_event_AdjustmentEvent_H_

// Forward structure declarations
struct _jc_java_awt_Adjustable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_AdjustmentEvent$sub_refs	_jc_java_awt_event_AdjustmentEvent$sub_refs;
typedef struct _jc_java_awt_event_AdjustmentEvent$sub_nonrefs	_jc_java_awt_event_AdjustmentEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_AdjustmentEvent$refs	_jc_java_awt_event_AdjustmentEvent$refs;
typedef struct _jc_java_awt_event_AdjustmentEvent$nonrefs	_jc_java_awt_event_AdjustmentEvent$nonrefs;
typedef struct _jc_java_awt_event_AdjustmentEvent$object	_jc_java_awt_event_AdjustmentEvent$object;

typedef struct _jc_java_awt_event_AdjustmentEvent$fields_struct	_jc_java_awt_event_AdjustmentEvent$fields_struct;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vmethods	_jc_java_awt_event_AdjustmentEvent$vmethods;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vtable	_jc_java_awt_event_AdjustmentEvent$vtable;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vtype	_jc_java_awt_event_AdjustmentEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_AdjustmentEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ADJUSTMENT__5fFIRST;
	jint	ADJUSTMENT__5fLAST;
	jint	ADJUSTMENT__5fVALUE__5fCHANGED;
	jint	BLOCK__5fDECREMENT;
	jint	BLOCK__5fINCREMENT;
	jint	TRACK;
	jint	UNIT__5fDECREMENT;
	jint	UNIT__5fINCREMENT;
};
extern _jc_java_awt_event_AdjustmentEvent$fields_struct _jc_java_awt_event_AdjustmentEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_AdjustmentEvent$method$_init$67d16fe80c9fa6e7(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *, struct _jc_object *, jint, jint, jint);
extern void _jc_java_awt_event_AdjustmentEvent$method$_init$858a8dee6f6e3aa1(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *, struct _jc_object *, jint, jint, jint, jboolean);

// Virtual methods
extern struct _jc_object *_jc_java_awt_event_AdjustmentEvent$method$getAdjustable$afbeb22cebf2426f(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
extern jint _jc_java_awt_event_AdjustmentEvent$method$getAdjustmentType$f1cff15bec6cfc1a(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
extern jint _jc_java_awt_event_AdjustmentEvent$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
extern jboolean _jc_java_awt_event_AdjustmentEvent$method$getValueIsAdjusting$927e01af49261dcb(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_AdjustmentEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getAdjustable$afbeb22cebf2426f;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getAdjustmentType$f1cff15bec6cfc1a;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getValueIsAdjusting$927e01af49261dcb;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_AdjustmentEvent$vmethods {
	struct _jc_object	*(*getAdjustable$afbeb22cebf2426f)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
	jint	(*getAdjustmentType$f1cff15bec6cfc1a)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
	jboolean	(*getValueIsAdjusting$927e01af49261dcb)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *);
};

// Vtable
struct _jc_java_awt_event_AdjustmentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_AdjustmentEvent$vmethods	java_awt_event_AdjustmentEvent;
};

// Vtype
struct _jc_java_awt_event_AdjustmentEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_AdjustmentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_AdjustmentEvent$sub_refs {
	struct _jc_object	*adjustable;
};

// Reference instance fields (object)
struct _jc_java_awt_event_AdjustmentEvent$refs {
    _jc_java_awt_event_AdjustmentEvent$sub_refs	java_awt_event_AdjustmentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_AdjustmentEvent$sub_nonrefs {
	jint	adjustmentType;
	jint	value;
	jboolean	isAdjusting;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_AdjustmentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_AdjustmentEvent$sub_nonrefs	java_awt_event_AdjustmentEvent;
};

// Object instance structure
struct _jc_java_awt_event_AdjustmentEvent$object {
	_jc_java_awt_event_AdjustmentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_AdjustmentEvent$vtype	*vtype;
	_jc_java_awt_event_AdjustmentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_AdjustmentEvent$vtype _jc_java_awt_event_AdjustmentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_AdjustmentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_AdjustmentEvent$class_object;

#endif	/* _JC_java_awt_event_AdjustmentEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/AdjustmentEvent.h <==
// public class java.awt.event.AdjustmentEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 7367f28289e75fa5 java_awt_event_AdjustmentEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_AdjustmentEvent_H_
#define _JC_java_awt_event_AdjustmentEvent_H_

// Forward structure declarations
struct _jc_java_awt_Adjustable$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_AdjustmentEvent$sub_refs	_jc_java_awt_event_AdjustmentEvent$sub_refs;
typedef struct _jc_java_awt_event_AdjustmentEvent$sub_nonrefs	_jc_java_awt_event_AdjustmentEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_AdjustmentEvent$refs	_jc_java_awt_event_AdjustmentEvent$refs;
typedef struct _jc_java_awt_event_AdjustmentEvent$nonrefs	_jc_java_awt_event_AdjustmentEvent$nonrefs;
typedef struct _jc_java_awt_event_AdjustmentEvent$object	_jc_java_awt_event_AdjustmentEvent$object;

typedef struct _jc_java_awt_event_AdjustmentEvent$fields_struct	_jc_java_awt_event_AdjustmentEvent$fields_struct;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vmethods	_jc_java_awt_event_AdjustmentEvent$vmethods;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vtable	_jc_java_awt_event_AdjustmentEvent$vtable;
typedef const struct _jc_java_awt_event_AdjustmentEvent$vtype	_jc_java_awt_event_AdjustmentEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_AdjustmentEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ADJUSTMENT__5fFIRST;
	jint	ADJUSTMENT__5fLAST;
	jint	ADJUSTMENT__5fVALUE__5fCHANGED;
	jint	BLOCK__5fDECREMENT;
	jint	BLOCK__5fINCREMENT;
	jint	TRACK;
	jint	UNIT__5fDECREMENT;
	jint	UNIT__5fINCREMENT;
};
extern _jc_java_awt_event_AdjustmentEvent$fields_struct _jc_java_awt_event_AdjustmentEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_AdjustmentEvent$method$_init$67d16fe80c9fa6e7(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *, struct _jc_object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_AdjustmentEvent$method$_init$858a8dee6f6e3aa1(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *, struct _jc_object *, jint, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_event_AdjustmentEvent$method$getAdjustable$afbeb22cebf2426f(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_AdjustmentEvent$method$getAdjustmentType$f1cff15bec6cfc1a(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_AdjustmentEvent$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_AdjustmentEvent$method$getValueIsAdjusting$927e01af49261dcb(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_AdjustmentEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getAdjustable$afbeb22cebf2426f;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getAdjustmentType$f1cff15bec6cfc1a;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$getValueIsAdjusting$927e01af49261dcb;
extern _jc_method _jc_java_awt_event_AdjustmentEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_AdjustmentEvent$vmethods {
	struct _jc_object	*(*getAdjustable$afbeb22cebf2426f)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
	jint	(*getAdjustmentType$f1cff15bec6cfc1a)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*getValueIsAdjusting$927e01af49261dcb)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_AdjustmentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_AdjustmentEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_AdjustmentEvent$vmethods	java_awt_event_AdjustmentEvent;
};

// Vtype
struct _jc_java_awt_event_AdjustmentEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_AdjustmentEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_AdjustmentEvent$sub_refs {
	struct _jc_object	*adjustable;
};

// Reference instance fields (object)
struct _jc_java_awt_event_AdjustmentEvent$refs {
    _jc_java_awt_event_AdjustmentEvent$sub_refs	java_awt_event_AdjustmentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_AdjustmentEvent$sub_nonrefs {
	jint	adjustmentType;
	jint	value;
	jboolean	isAdjusting;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_AdjustmentEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_AdjustmentEvent$sub_nonrefs	java_awt_event_AdjustmentEvent;
};

// Object instance structure
struct _jc_java_awt_event_AdjustmentEvent$object {
	_jc_java_awt_event_AdjustmentEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_AdjustmentEvent$vtype	*vtype;
	_jc_java_awt_event_AdjustmentEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_AdjustmentEvent$vtype _jc_java_awt_event_AdjustmentEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_AdjustmentEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_AdjustmentEvent$class_object;

#endif	/* _JC_java_awt_event_AdjustmentEvent_H_ */
